#!/usr/bin/perl

use strict;
use Test::More tests => 47;
use FDN::Common::Logger;

# 1
BEGIN { use_ok('FDN::Common::Utils'); }

# 2
BEGIN { use_ok('FDN::Common::Validate'); }

my $ts;
$ts = get_timestamp(TIMESTAMP_DB);

# 3
ok ( Is_TimestampDB($ts), 'tsdb' );

$ts = get_timestamp(TIMESTAMP_14);

# 4
ok ( Is_Timestamp14($ts), 'ts14' );

$ts = get_timestamp(TIMESTAMP_8);

# 5
ok ( Is_Timestamp8($ts), 'ts8' );

$ts = get_timestamp();

# 6
ok ( Is_TimestampDB($ts), 'tsdflt');

$ts = get_timestamp(TIMESTAMP_14);
my $epoch;
$epoch = timestamp14_2_epoch($ts);
my $ts2;
$ts2 = epoch_2_timestamp14($epoch);

# 7
is ( $ts, $ts2, 'epoch');

$ts = '20050531223435';
$ts2 = '2005-05-31 22:34:35';

# 8
is ( timestamp14_2_db($ts), $ts2, 'ts');

# 9
is ( timestampdb_2_14($ts2), $ts, 'ts');

# 10
is ( convert_unit(1540,'k',1000), '1,54 M', 'unit');

# 11
is ( convert_unit(1541,'k',1000), '1,54 M', 'unit');

# 12
test(1, '', 1024, undef, '1 ');
# 13
test(1024, 'k', 1024, undef, '1 M');
# 14
test(512, 'k', 1024, undef, '512 k');
# 15
test(1024*1024, 'k', 1024, undef, '1 G');
# 16
test(1, 'M', 1024, undef, '1 M');
# 17
test(1024 ** 3, '', 1024, undef, '1 G');
# 18
test(3654, 'M', 1024, undef, '3,57 G');
# 19
test(3654, 'M', 1000, undef, '3,65 G');
# 20
test(3654000000, '', 1000, undef, '3,65 G');
# 21
test(3655000, '', 1000, undef, '3,66 M');
# 22
test(3655123, '', 1000, undef, '3,66 M');
# 23
test(3655123, '', 1000, 4, '3,655 M');
# 24
test_list(3654, 'M', 1024, '3,57', 'G');
# 25
test(123456789, '', 1000, 9, '123,456789 M');
# 26
test('1234'.'0'x56, '', 1024, 35, '1,02074087589044e+35 Y');
# 27
test('1234'.'0'x56, '', 1024, 3, '1,02e+35 Y');
# 28
test(1234, '', -1000, 3, undef);
# 29
test(1234, '', 1000, 0, '1 k');

sub test {
	my ($number, $prefix, $divisor, $min, $attendu) = @_;
	my $output = convert_unit($number, $prefix, $divisor, $min);
	is($output, $attendu, "'$number $prefix' ($divisor) -> '".(defined($attendu)?$attendu:'')."'");
}

sub test_list {
	my ($number, $prefix, $divisor, $attendu_nombre, $attendu_prefixe) = @_;
	my @output = convert_unit($number, $prefix, $divisor);
	ok(eq_array(\@output, [$attendu_nombre, $attendu_prefixe]), "'$number $prefix' ($divisor) -> ('$attendu_nombre', '$attendu_prefixe')");
}

my $str1;
my $str2;
$str1='Benjamin Bayart';
$str2=make_string_rfc822($str1);

# 30
is ( $str2, 'benjamin.bayart', 'rfc822');

$str1='variste';
$str2=make_string_rfc822($str1);

# 31
is ( $str2, 'evariste', 'rfc822');

# 32
is ( convert_time(60,'s','m'), 1, 'time');

# 33
is ( convert_time(60,'m','s'), 3600, 'time');

# 34
is ( convert_time(1, 'h', 'm'), 60, 'time');

# 35
is ( make_alpha_hashing('benjamin',3), '/b/be/ben', 'hash1');

# 36
is ( make_alpha_hashing('b',3), '/b/b/b', 'hash1');

# 37
is ( make_alpha_hashing('RiEn',3), '/R/Ri/RiE', 'hash1');

# 38
is ( make_alpha_hashing('rien',0), '', 'hash1');

# 39
is ( make_crc32_hashing('benjamin',4), '/12/be/4e/8f', 'hash2');

# 40
is ( make_crc32_hashing('benjamin',5), undef, 'hash2');

# 41
is ( make_crc32_hashing('benjamin',1), '/12', 'hash2');

# 42
is ( make_crc32_hashing('benjamin',0), '', 'hash2');

# 43
$str1 = 'benjamin';
$str2 = dir_hashing('alpha',$str1,3,3);
is_deeply($str2,['/b/be/ben','/b/be','/b',''],'hash3');

# 44
is ( get_last_error_msg(), '', 'hash3');

# 45
$str2 = dir_hashing('alpha','b',3,3);
is_deeply($str2,['/b/b/b','/b/b','/b',''],'hash3');

# 46
$str2 = dir_hashing('crc32',$str1,3,1);
is_deeply($str2,['/12/be/4e','/12/be'],'hash3');

# 47
$str2 = dir_hashing('crc32',$str1,4,0);
is_deeply($str2,['/12/be/4e/8f'],'hash3');





